==> httpmime-4.0-beta1-sources.jar: org/apache/http/entity/mime/MIME.java <==
/*
 * $HeadURL: https://svn.apache.org/repos/asf/httpcomponents/httpclient/tags/4.0-beta1/module-httpmime/src/main/java/org/apache/http/entity/mime/MIME.java $
 * $Revision: 618333 $
 * $Date: 2008-02-04 18:27:24 +0100 (Mon, 04 Feb 2008) $
 *
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.apache.http.entity.mime;

import java.nio.charset.Charset;

import org.apache.james.mime4j.field.Field;
import org.apache.james.mime4j.util.CharsetUtil;

public final class MIME {

    public static final String CONTENT_TYPE          = Field.CONTENT_TYPE;
    public static final String CONTENT_TRANSFER_ENC  = Field.CONTENT_TRANSFER_ENCODING;
    public static final String CONTENT_DISPOSITION   = "Content-Disposition";
 
    public static final String ENC_8BIT              = "8bit";
    public static final String ENC_BINARY            = "binary";

    public static final Charset DEFAULT_CHARSET      = CharsetUtil.getCharset("US-ASCII");
    
}

==> httpmime-4.1-beta1-sources.jar: org/apache/http/entity/mime/MIME.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.apache.http.entity.mime;

import java.nio.charset.Charset;

/**
 *
 * @since 4.0
 */
public final class MIME {

    public static final String CONTENT_TYPE          = "Content-Type";
    public static final String CONTENT_TRANSFER_ENC  = "Content-Transfer-Encoding";
    public static final String CONTENT_DISPOSITION   = "Content-Disposition";

    public static final String ENC_8BIT              = "8bit";
    public static final String ENC_BINARY            = "binary";

    public static final Charset DEFAULT_CHARSET      = Charset.forName("US-ASCII");

}
